@@ -5,6 +5,7 @@ Repository List Command
 
 #include <unistd.h>
 
+#include "command/repo/common.h"
 #include "common/debug.h"
 #include "common/io/fdWrite.h"
 #include "common/log.h"
@@ -18,80 +19,59 @@ Repository List Command
 /***********************************************************************************************************************************
 Render storage list
 ***********************************************************************************************************************************/
-typedef struct StorageListRenderCallbackData
-{
-    IoWrite *write;                                                 // Where to write output
-    bool json;                                                      // Is this json output?
-    bool first;                                                     // Is this the first item?
-} StorageListRenderCallbackData;
-
-void
-storageListRenderCallback(void *data, const StorageInfo *info)
+static void
+storageListRenderInfo(const StorageInfo *const info, IoWrite *const write, const bool json)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM_P(VOID, data);
         FUNCTION_TEST_PARAM(STORAGE_INFO, info);
+        FUNCTION_TEST_PARAM(IO_WRITE, write);
+        FUNCTION_TEST_PARAM(BOOL, json);
     FUNCTION_TEST_END();
 
-    ASSERT(data != NULL);
     ASSERT(info != NULL);
-
-    StorageListRenderCallbackData *listData = (StorageListRenderCallbackData *)data;
-
-    // Skip . path if it is not first when json output
-    if (info->type == storageTypePath && strEq(info->name, DOT_STR) && (!listData->first || !listData->json))
-    {
-        FUNCTION_TEST_RETURN_VOID();
-        return;
-    }
-
-    // Add separator character
-    if (!listData->first && listData->json)
-        ioWrite(listData->write, COMMA_BUF);
-    else
-        listData->first = false;
+    ASSERT(write != NULL);
 
     // Render in json
-    if (listData->json)
+    if (json)
     {
-        ioWriteStr(listData->write, jsonFromStr(info->name));
-        ioWrite(listData->write, BUFSTRDEF(":{\"type\":\""));
+        ioWriteStr(write, jsonFromVar(VARSTR(info->name)));
+        ioWrite(write, BUFSTRDEF(":{\"type\":\""));
 
         switch (info->type)
         {
             case storageTypeFile:
-                ioWrite(listData->write, BUFSTRDEF("file\""));
+                ioWrite(write, BUFSTRDEF("file\""));
                 break;
 
             case storageTypeLink:
-                ioWrite(listData->write, BUFSTRDEF("link\""));
+                ioWrite(write, BUFSTRDEF("link\""));
                 break;
 
             case storageTypePath:
-                ioWrite(listData->write, BUFSTRDEF("path\""));
+                ioWrite(write, BUFSTRDEF("path\""));
                 break;
 
             case storageTypeSpecial:
-                ioWrite(listData->write, BUFSTRDEF("special\""));
+                ioWrite(write, BUFSTRDEF("special\""));
                 break;
         }
 
         if (info->type == storageTypeFile)
         {
-            ioWriteStr(listData->write, strNewFmt(",\"size\":%" PRIu64, info->size));
-            ioWriteStr(listData->write, strNewFmt(",\"time\":%" PRId64, (int64_t)info->timeModified));
+            ioWriteStr(write, strNewFmt(",\"size\":%" PRIu64, info->size));
+            ioWriteStr(write, strNewFmt(",\"time\":%" PRId64, (int64_t)info->timeModified));
         }
 
         if (info->type == storageTypeLink)
-            ioWriteStr(listData->write, strNewFmt(",\"destination\":%s", strZ(jsonFromStr(info->linkDestination))));
+            ioWriteStr(write, strNewFmt(",\"destination\":%s", strZ(jsonFromVar(VARSTR(info->linkDestination)))));
 
-        ioWrite(listData->write, BRACER_BUF);
+        ioWrite(write, BRACER_BUF);
     }
     // Render in text
     else
     {
-        ioWrite(listData->write, BUFSTR(info->name));
-        ioWrite(listData->write, LF_BUF);
+        ioWrite(write, BUFSTR(info->name));
+        ioWrite(write, LF_BUF);
     }
 
     FUNCTION_TEST_RETURN_VOID();
@@ -124,14 +104,9 @@ storageListRender(IoWrite *write)
     // Get path
     const String *path = NULL;
 
+    // Get and validate if path is valid for repo
     if (strLstSize(cfgCommandParam()) == 1)
-    {
-        path = strLstGet(cfgCommandParam(), 0);
-
-        // Make sure the path does not end with a slash unless it is only /
-        if (strEndsWith(path, FSLASH_STR) && strSize(path) > 1)
-            path = strPath(path);
-    }
+        path = repoPathIsValid(strLstGet(cfgCommandParam(), 0));
     else if (strLstSize(cfgCommandParam()) > 1)
         THROW(ParamInvalidError, "only one path may be specified");
 
@@ -140,18 +115,10 @@ storageListRender(IoWrite *write)
     const String *expression = cfgOptionStrNull(cfgOptFilter);
     RegExp *regExp = expression == NULL ? NULL : regExpNew(expression);
 
-    // Render the info list
-    StorageListRenderCallbackData data =
-    {
-        .write = write,
-        .json = json,
-        .first = true,
-    };
+    ioWriteOpen(write);
 
-    ioWriteOpen(data.write);
-
-    if (data.json)
-        ioWrite(data.write, BRACEL_BUF);
+    if (json)
+        ioWrite(write, BRACEL_BUF);
 
     // Check if this is a file
     StorageInfo info = storageInfoP(storageRepo(), path, .ignoreMissing = true);
@@ -161,29 +128,46 @@ storageListRender(IoWrite *write)
         if (regExp == NULL || regExpMatch(regExp, storagePathP(storageRepo(), path)))
         {
             info.name = DOT_STR;
-            storageListRenderCallback(&data, &info);
+            storageListRenderInfo(&info, write, json);
         }
     }
     // Else try to list the path
     else
     {
         // The path will always be reported as existing so we don't get different results from storage that does not support paths
-        if (data.json && (regExp == NULL || regExpMatch(regExp, DOT_STR)))
-            storageListRenderCallback(&data, &(StorageInfo){.type = storageTypePath, .name = DOT_STR});
+        bool first = true;
+
+        if (json && (regExp == NULL || regExpMatch(regExp, DOT_STR)))
+        {
+            storageListRenderInfo(&(StorageInfo){.type = storageTypePath, .name = DOT_STR}, write, json);
+            first = false;
+        }
 
         // List content of the path
-        storageInfoListP(
-            storageRepo(), path, storageListRenderCallback, &data, .sortOrder = sortOrder, .expression = expression,
-            .recurse = cfgOptionBool(cfgOptRecurse));
+        StorageIterator *const storageItr = storageNewItrP(
+            storageRepo(), path, .sortOrder = sortOrder, .expression = expression, .recurse = cfgOptionBool(cfgOptRecurse));
+
+        while (storageItrMore(storageItr))
+        {
+            const StorageInfo info = storageItrNext(storageItr);
+
+            // Add separator character
+            if (!first && json)
+                ioWrite(write, COMMA_BUF);
+            else
+                first = false;
+
+            storageListRenderInfo(&info, write, json);
+        }
     }
 
-    if (data.json)
+    if (json)
     {
-        ioWrite(data.write, BRACER_BUF);
-        ioWrite(data.write, LF_BUF);
+        ioWrite(write, BRACER_BUF);
+        ioWrite(write, LF_BUF);
     }
 
-    ioWriteClose(data.write);
+    ioWriteClose(write);
 
     FUNCTION_LOG_RETURN_VOID();
 }
