@@ -9,6 +9,6 @@ Server Command
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-void cmdServer(uint64_t connectionMax);
+void cmdServer(unsigned int argListSize, const char *argList[]);
 
 #endif
