@@ -78,7 +78,7 @@ sckClientOpen(THIS_VOID)
         {
             // Assume there will be no retry
             retry = false;
-            int fd = -1;
+            volatile int fd = -1;
 
             TRY_BEGIN()
             {
@@ -146,7 +146,7 @@ sckClientName(THIS_VOID)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(this->name);
+    FUNCTION_TEST_RETURN_CONST(STRING, this->name);
 }
 
 /**********************************************************************************************************************************/
@@ -172,7 +172,7 @@ sckClientNew(const String *const host, const unsigned int port, const TimeMSec t
 
     IoClient *this = NULL;
 
-    OBJ_NEW_BEGIN(SocketClient)
+    OBJ_NEW_BEGIN(SocketClient, .childQty = MEM_CONTEXT_QTY_MAX, .allocQty = MEM_CONTEXT_QTY_MAX)
     {
         SocketClient *driver = OBJ_NEW_ALLOC();
 
