@@ -12,6 +12,7 @@ Convert C Types
 #include <time.h>
 
 #include "common/debug.h"
+#include "common/macro.h"
 #include "common/type/convert.h"
 
 /***********************************************************************************************************************************
@@ -62,7 +63,7 @@ cvtZToInt64Internal(const char *value, const char *type, int base)
     // Validate the result
     cvtZToIntValid(errno, base, value, endPtr, type);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(INT64, result);
 }
 
 /***********************************************************************************************************************************
@@ -87,7 +88,7 @@ cvtZToUInt64Internal(const char *value, const char *type, int base)
     // Validate the result
     cvtZToIntValid(errno, base, value, endPtr, type);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(UINT64, result);
 }
 
 /**********************************************************************************************************************************/
@@ -107,7 +108,7 @@ cvtBoolToZ(bool value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
 const char *
@@ -133,7 +134,7 @@ cvtCharToZ(char value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
 /**********************************************************************************************************************************/
@@ -177,7 +178,7 @@ cvtDoubleToZ(double value, char *buffer, size_t bufferSize)
     end[1] = 0;
 
     // Return string length
-    FUNCTION_TEST_RETURN((size_t)(end - buffer + 1));
+    FUNCTION_TEST_RETURN(SIZE, (size_t)(end - buffer + 1));
 }
 
 double
@@ -195,7 +196,7 @@ cvtZToDouble(const char *value)
     if (result == 0 && strcmp(value, "0") != 0)
         THROW_FMT(FormatError, "unable to convert string '%s' to double", value);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(DOUBLE, result);
 }
 
 /**********************************************************************************************************************************/
@@ -215,7 +216,7 @@ cvtIntToZ(int value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
 int
@@ -232,7 +233,7 @@ cvtZToIntBase(const char *value, int base)
     if (result > INT_MAX || result < INT_MIN)
         THROW_FMT(FormatError, "unable to convert base %d string '%s' to int", base, value);
 
-    FUNCTION_TEST_RETURN((int)result);
+    FUNCTION_TEST_RETURN(INT, (int)result);
 }
 
 int
@@ -244,7 +245,27 @@ cvtZToInt(const char *value)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN(cvtZToIntBase(value, 10));
+    FUNCTION_TEST_RETURN(INT, cvtZToIntBase(value, 10));
+}
+
+int
+cvtZSubNToIntBase(const char *const value, const size_t offset, const size_t size, const int base)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRINGZ, value);
+        FUNCTION_TEST_PARAM(SIZE, offset);
+        FUNCTION_TEST_PARAM(SIZE, size);
+        FUNCTION_TEST_PARAM(INT, base);
+    FUNCTION_TEST_END();
+
+    ASSERT(value != NULL);
+
+    char buffer[CVT_BASE10_BUFFER_SIZE + 1];
+    ASSERT(size <= CVT_BASE10_BUFFER_SIZE);
+    strncpy(buffer, value + offset, size);
+    buffer[size] = '\0';
+
+    FUNCTION_TEST_RETURN(INT, cvtZToIntBase(buffer, base));
 }
 
 /**********************************************************************************************************************************/
@@ -264,7 +285,7 @@ cvtInt64ToZ(int64_t value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
 int64_t
@@ -276,7 +297,7 @@ cvtZToInt64Base(const char *value, int base)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN(cvtZToInt64Internal(value, "int64", base));
+    FUNCTION_TEST_RETURN(INT64, cvtZToInt64Internal(value, "int64", base));
 }
 
 int64_t
@@ -288,7 +309,27 @@ cvtZToInt64(const char *value)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN(cvtZToInt64Base(value, 10));
+    FUNCTION_TEST_RETURN(INT64, cvtZToInt64Base(value, 10));
+}
+
+int64_t
+cvtZSubNToInt64Base(const char *const value, const size_t offset, const size_t size, const int base)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRINGZ, value);
+        FUNCTION_TEST_PARAM(SIZE, offset);
+        FUNCTION_TEST_PARAM(SIZE, size);
+        FUNCTION_TEST_PARAM(INT, base);
+    FUNCTION_TEST_END();
+
+    ASSERT(value != NULL);
+
+    char buffer[CVT_BASE10_BUFFER_SIZE + 1];
+    ASSERT(size <= CVT_BASE10_BUFFER_SIZE);
+    strncpy(buffer, value + offset, size);
+    buffer[size] = '\0';
+
+    FUNCTION_TEST_RETURN(INT64, cvtZToInt64Base(buffer, base));
 }
 
 /**********************************************************************************************************************************/
@@ -308,7 +349,7 @@ cvtModeToZ(mode_t value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
 mode_t
@@ -320,7 +361,7 @@ cvtZToMode(const char *value)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN((mode_t)cvtZToUIntBase(value, 8));
+    FUNCTION_TEST_RETURN(MODE, (mode_t)cvtZToUIntBase(value, 8));
 }
 
 /**********************************************************************************************************************************/
@@ -340,7 +381,7 @@ cvtSizeToZ(size_t value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
 size_t
@@ -359,7 +400,7 @@ cvtSSizeToZ(ssize_t value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
 /**********************************************************************************************************************************/
@@ -380,7 +421,7 @@ cvtTimeToZ(time_t value, char *buffer, size_t bufferSize)
     if (result == 0)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
 /**********************************************************************************************************************************/
@@ -400,7 +441,7 @@ cvtUIntToZ(unsigned int value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
 unsigned int
@@ -418,7 +459,7 @@ cvtZToUIntBase(const char *value, int base)
     if (*value == '-' || result > UINT_MAX)
         THROW_FMT(FormatError, "unable to convert base %d string '%s' to unsigned int", base, value);
 
-    FUNCTION_TEST_RETURN((unsigned int)result);
+    FUNCTION_TEST_RETURN(UINT, (unsigned int)result);
 }
 
 unsigned int
@@ -430,7 +471,27 @@ cvtZToUInt(const char *value)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN(cvtZToUIntBase(value, 10));
+    FUNCTION_TEST_RETURN(UINT, cvtZToUIntBase(value, 10));
+}
+
+unsigned int
+cvtZSubNToUIntBase(const char *const value, const size_t offset, const size_t size, const int base)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRINGZ, value);
+        FUNCTION_TEST_PARAM(SIZE, offset);
+        FUNCTION_TEST_PARAM(SIZE, size);
+        FUNCTION_TEST_PARAM(INT, base);
+    FUNCTION_TEST_END();
+
+    ASSERT(value != NULL);
+
+    char buffer[CVT_BASE10_BUFFER_SIZE + 1];
+    ASSERT(size <= CVT_BASE10_BUFFER_SIZE);
+    strncpy(buffer, value + offset, size);
+    buffer[size] = '\0';
+
+    FUNCTION_TEST_RETURN(UINT, cvtZToUIntBase(buffer, base));
 }
 
 /**********************************************************************************************************************************/
@@ -450,7 +511,7 @@ cvtUInt64ToZ(uint64_t value, char *buffer, size_t bufferSize)
     if (result >= bufferSize)
         THROW(AssertError, "buffer overflow");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(SIZE, result);
 }
 
 uint64_t
@@ -468,7 +529,7 @@ cvtZToUInt64Base(const char *value, int base)
     if (*value == '-')
         THROW_FMT(FormatError, "unable to convert base %d string '%s' to uint64", base, value);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(UINT64, result);
 }
 
 uint64_t
@@ -480,7 +541,27 @@ cvtZToUInt64(const char *value)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN(cvtZToUInt64Base(value, 10));
+    FUNCTION_TEST_RETURN(UINT64, cvtZToUInt64Base(value, 10));
+}
+
+uint64_t
+cvtZSubNToUInt64Base(const char *const value, const size_t offset, const size_t size, const int base)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRINGZ, value);
+        FUNCTION_TEST_PARAM(SIZE, offset);
+        FUNCTION_TEST_PARAM(SIZE, size);
+        FUNCTION_TEST_PARAM(INT, base);
+    FUNCTION_TEST_END();
+
+    ASSERT(value != NULL);
+
+    char buffer[CVT_BASE10_BUFFER_SIZE + 1];
+    ASSERT(size <= CVT_BASE10_BUFFER_SIZE);
+    strncpy(buffer, value + offset, size);
+    buffer[size] = '\0';
+
+    FUNCTION_TEST_RETURN(UINT64, cvtZToUInt64Base(buffer, base));
 }
 
 /**********************************************************************************************************************************/
@@ -557,5 +638,5 @@ cvtUInt64FromVarInt128(const uint8_t *const value, size_t *const valuePos)
     if (byte >= 0x80)
         THROW(FormatError, "unterminated varint-128 integer");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(UINT64, result);
 }
