@@ -35,7 +35,7 @@ Integer types (packTypeMapData[type].valueMultiBit) when an unsigned value is <=
             1 0 0 1 - the low-order bit is 1 so the "ID delta low order bit" is set.
     04 = since the low order bit of the internal ID delta was already set in bit 0 of the tag byte, then the remain bits are shifted
         right by one and represented in this second byte as 4. To get the ID delta for 04, shift the 4 back to the left one and then
-        add back the "ID delta low order bit" to give a binary representation of  1 0 0 1 = 9. Add back the 1 which is never
+        add back the "ID delta low order bit" to give a binary representation of 1 0 0 1 = 9. Add back the 1 which is never
         recorded and the ID gap is 10.
 
 Integer types (packTypeMapData[type].valueMultiBit) when an unsigned value is > 1 or a signed value is < -1 or > 0:
@@ -81,7 +81,7 @@ Array and object types:
 0-2 - ID delta low order bits
   Note: arrays and objects are merely containers for the other pack types.
 
-  Example: 1801  (container begin)
+  Example: 1801 (container begin)
     1 = array type
     8 = "more ID delta indicator bit" - there exists a gap (i.e. NULLs are not stored so there is a gap between the stored IDs)
     01 = since there are three "ID delta low order bits", the 01 will be shifted left by 3 with zeros, resulting in 8. Add back
@@ -210,8 +210,6 @@ static const PackTypeMapData packTypeMapData[] =
     },
 };
 
-#define PACK_TYPE_MAP_SIZE                                          (sizeof(packTypeMapData) / sizeof(PackTypeMapData))
-
 /***********************************************************************************************************************************
 Object types
 ***********************************************************************************************************************************/
@@ -338,7 +336,7 @@ pckReadNewInternal(void)
 
     PackRead *this = NULL;
 
-    OBJ_NEW_BEGIN(PackRead)
+    OBJ_NEW_BEGIN(PackRead, .childQty = MEM_CONTEXT_QTY_MAX)
     {
         this = OBJ_NEW_ALLOC();
 
@@ -351,7 +349,7 @@ pckReadNewInternal(void)
     }
     OBJ_NEW_END();
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_READ, this);
 }
 
 PackRead *
@@ -365,15 +363,15 @@ pckReadNewIo(IoRead *read)
 
     PackRead *this = pckReadNewInternal();
 
-    MEM_CONTEXT_BEGIN(objMemContext(this))
+    MEM_CONTEXT_OBJ_BEGIN(this)
     {
         this->read = read;
         this->buffer = bufNew(ioBufferSize());
         this->bufferPtr = bufPtr(this->buffer);
     }
-    MEM_CONTEXT_END();
+    MEM_CONTEXT_OBJ_END();
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_READ, this);
 }
 
 PackRead *
@@ -384,9 +382,9 @@ pckReadNew(const Pack *const pack)
     FUNCTION_TEST_END();
 
     if (pack == NULL)
-        FUNCTION_TEST_RETURN(NULL);
+        FUNCTION_TEST_RETURN(PACK_READ, NULL);
 
-    FUNCTION_TEST_RETURN(pckReadNewC(bufPtrConst((const Buffer *)pack), bufUsed((const Buffer *)pack)));
+    FUNCTION_TEST_RETURN(PACK_READ, pckReadNewC(bufPtrConst((const Buffer *)pack), bufUsed((const Buffer *)pack)));
 }
 
 PackRead *
@@ -403,7 +401,7 @@ pckReadNewC(const unsigned char *const buffer, size_t size)
     this->bufferPtr = buffer;
     this->bufferUsed = size;
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_READ, this);
 }
 
 /***********************************************************************************************************************************
@@ -446,10 +444,10 @@ pckReadBuffer(PackRead *this, size_t size)
         if (remaining < 1)
             THROW(FormatError, "unexpected EOF");
 
-        FUNCTION_TEST_RETURN(remaining < size ? remaining : size);
+        FUNCTION_TEST_RETURN(SIZE, remaining < size ? remaining : size);
     }
 
-    FUNCTION_TEST_RETURN(size);
+    FUNCTION_TEST_RETURN(SIZE, size);
 }
 
 /***********************************************************************************************************************************
@@ -512,7 +510,7 @@ pckReadU64Internal(PackRead *this)
     if (byte >= 0x80)
         THROW(FormatError, "unterminated base-128 integer");
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(UINT64, result);
 }
 
 /***********************************************************************************************************************************
@@ -549,7 +547,7 @@ pckReadTagNext(PackRead *this)
             this->tagNextTypeMap = (unsigned int)pckReadU64Internal(this) + 0xF;
 
         CHECK(
-            FormatError, this->tagNextTypeMap < PACK_TYPE_MAP_SIZE && packTypeMapData[this->tagNextTypeMap].type != 0,
+            FormatError, this->tagNextTypeMap < LENGTH_OF(packTypeMapData) && packTypeMapData[this->tagNextTypeMap].type != 0,
             "invalid tag type");
 
         // If the value can contain multiple bits (e.g. integer)
@@ -625,7 +623,7 @@ pckReadTagNext(PackRead *this)
         result = true;
     }
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(BOOL, result);
 }
 
 /***********************************************************************************************************************************
@@ -700,7 +698,7 @@ pckReadTag(PackRead *this, unsigned int *id, PackTypeMap typeMap, bool peek)
     }
     while (1);
 
-    FUNCTION_TEST_RETURN(this->tagNextValue);
+    FUNCTION_TEST_RETURN(UINT64, this->tagNextValue);
 }
 
 /**********************************************************************************************************************************/
@@ -714,7 +712,7 @@ pckReadNext(PackRead *this)
     ASSERT(this != NULL);
     ASSERT(this->tagNextId == 0);
 
-    FUNCTION_TEST_RETURN(pckReadTagNext(this));
+    FUNCTION_TEST_RETURN(BOOL, pckReadTagNext(this));
 }
 
 /**********************************************************************************************************************************/
@@ -727,7 +725,7 @@ pckReadId(PackRead *this)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(this->tagNextId);
+    FUNCTION_TEST_RETURN(UINT, this->tagNextId);
 }
 
 /**********************************************************************************************************************************/
@@ -741,7 +739,7 @@ pckReadSize(PackRead *this)
     ASSERT(this != NULL);
     ASSERT(packTypeMapData[this->tagNextTypeMap].size);
 
-    FUNCTION_TEST_RETURN(this->tagNextSize);
+    FUNCTION_TEST_RETURN(SIZE, this->tagNextSize);
 }
 
 /**********************************************************************************************************************************/
@@ -775,7 +773,7 @@ pckReadBufPtr(PackRead *this)
     ASSERT(packTypeMapData[this->tagNextTypeMap].size);
     ASSERT(this->buffer == NULL);
 
-    FUNCTION_TEST_RETURN(this->bufferPtr + this->bufferPos);
+    FUNCTION_TEST_RETURN_CONST_P(UCHARDATA, this->bufferPtr + this->bufferPos);
 }
 
 /**********************************************************************************************************************************/
@@ -799,11 +797,11 @@ pckReadNullInternal(PackRead *this, unsigned int *id)
     if (*id < this->tagNextId)
     {
         this->tagStack.top->idLast = *id;
-        FUNCTION_TEST_RETURN(true);
+        FUNCTION_TEST_RETURN(BOOL, true);
     }
 
     // The field is not NULL
-    FUNCTION_TEST_RETURN(false);
+    FUNCTION_TEST_RETURN(BOOL, false);
 }
 
 bool
@@ -816,7 +814,7 @@ pckReadNull(PackRead *this, PackIdParam param)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(pckReadNullInternal(this, &param.id));
+    FUNCTION_TEST_RETURN(BOOL, pckReadNullInternal(this, &param.id));
 }
 
 /**********************************************************************************************************************************/
@@ -829,7 +827,7 @@ pckReadType(PackRead *this)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(packTypeMapData[this->tagNextTypeMap].type);
+    FUNCTION_TEST_RETURN(STRING_ID, packTypeMapData[this->tagNextTypeMap].type);
 }
 
 /**********************************************************************************************************************************/
@@ -889,7 +887,7 @@ pckReadBin(PackRead *this, PckReadBinParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(NULL);
+        FUNCTION_TEST_RETURN(BUFFER, NULL);
 
     Buffer *result = NULL;
 
@@ -911,7 +909,7 @@ pckReadBin(PackRead *this, PckReadBinParam param)
     else
         result = bufNew(0);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(BUFFER, result);
 }
 
 /**********************************************************************************************************************************/
@@ -927,9 +925,9 @@ pckReadBool(PackRead *this, PckReadBoolParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(BOOL, param.defaultValue);
 
-    FUNCTION_TEST_RETURN(pckReadTag(this, &param.id, pckTypeMapBool, false));
+    FUNCTION_TEST_RETURN(BOOL, pckReadTag(this, &param.id, pckTypeMapBool, false));
 }
 
 /**********************************************************************************************************************************/
@@ -945,9 +943,9 @@ pckReadI32(PackRead *this, PckReadI32Param param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(INT, param.defaultValue);
 
-    FUNCTION_TEST_RETURN(cvtInt32FromZigZag((uint32_t)pckReadTag(this, &param.id, pckTypeMapI32, false)));
+    FUNCTION_TEST_RETURN(INT, cvtInt32FromZigZag((uint32_t)pckReadTag(this, &param.id, pckTypeMapI32, false)));
 }
 
 /**********************************************************************************************************************************/
@@ -963,9 +961,9 @@ pckReadI64(PackRead *this, PckReadI64Param param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(INT64, param.defaultValue);
 
-    FUNCTION_TEST_RETURN(cvtInt64FromZigZag(pckReadTag(this, &param.id, pckTypeMapI64, false)));
+    FUNCTION_TEST_RETURN(INT64, cvtInt64FromZigZag(pckReadTag(this, &param.id, pckTypeMapI64, false)));
 }
 
 /**********************************************************************************************************************************/
@@ -981,9 +979,9 @@ pckReadMode(PackRead *this, PckReadModeParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(MODE, param.defaultValue);
 
-    FUNCTION_TEST_RETURN((mode_t)pckReadTag(this, &param.id, pckTypeMapMode, false));
+    FUNCTION_TEST_RETURN(MODE, (mode_t)pckReadTag(this, &param.id, pckTypeMapMode, false));
 }
 
 /**********************************************************************************************************************************/
@@ -1046,7 +1044,7 @@ pckReadPackRead(PackRead *this, PckReadPackParam param)
     if (result != NULL)
         pckMove(pack, objMemContext(result));
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(PACK_READ, result);
 }
 
 PackRead *
@@ -1058,7 +1056,7 @@ pckReadPackReadConst(PackRead *this, PckReadPackParam param)
     FUNCTION_TEST_END();
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(NULL);
+        FUNCTION_TEST_RETURN(PACK_READ, NULL);
 
     // Read the tag
     pckReadTag(this, &param.id, pckTypeMapPack, false);
@@ -1067,7 +1065,7 @@ pckReadPackReadConst(PackRead *this, PckReadPackParam param)
 
     pckReadConsumeBuffer(this);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(PACK_READ, result);
 }
 
 Pack *
@@ -1081,7 +1079,7 @@ pckReadPack(PackRead *const this, PckReadPackParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(NULL);
+        FUNCTION_TEST_RETURN(PACK, NULL);
 
     // Read the tag
     pckReadTag(this, &param.id, pckTypeMapPack, false);
@@ -1097,7 +1095,7 @@ pckReadPack(PackRead *const this, PckReadPackParam param)
         this->bufferPos += size;
     }
 
-    FUNCTION_TEST_RETURN((Pack *)result);
+    FUNCTION_TEST_RETURN(PACK, (Pack *)result);
 }
 
 /**********************************************************************************************************************************/
@@ -1112,9 +1110,9 @@ pckReadPtr(PackRead *this, PckReadPtrParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(NULL);
+        FUNCTION_TEST_RETURN_P(VOID, NULL);
 
-    FUNCTION_TEST_RETURN((void *)(uintptr_t)pckReadTag(this, &param.id, pckTypeMapPtr, false));
+    FUNCTION_TEST_RETURN_P(VOID, (void *)(uintptr_t)pckReadTag(this, &param.id, pckTypeMapPtr, false));
 }
 
 /**********************************************************************************************************************************/
@@ -1130,7 +1128,7 @@ pckReadStr(PackRead *this, PckReadStrParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(strDup(param.defaultValue));
+        FUNCTION_TEST_RETURN(STRING, strDup(param.defaultValue));
 
     String *result = NULL;
 
@@ -1154,7 +1152,7 @@ pckReadStr(PackRead *this, PckReadStrParam param)
     else
         result = strNew();
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(STRING, result);
 }
 
 /**********************************************************************************************************************************/
@@ -1170,9 +1168,9 @@ pckReadStrId(PackRead *this, PckReadStrIdParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(STRING_ID, param.defaultValue);
 
-    FUNCTION_TEST_RETURN(pckReadTag(this, &param.id, pckTypeMapStrId, false));
+    FUNCTION_TEST_RETURN(STRING_ID, pckReadTag(this, &param.id, pckTypeMapStrId, false));
 }
 
 /**********************************************************************************************************************************/
@@ -1187,18 +1185,22 @@ pckReadStrLst(PackRead *const this, PckReadStrLstParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(NULL);
+        FUNCTION_TEST_RETURN(STRING_LIST, NULL);
 
     pckReadArrayBeginP(this, .id = param.id);
 
     StringList *const result = strLstNew();
 
-    while (!pckReadNullP(this))
-        strLstAdd(result, pckReadStrP(this));
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        while (!pckReadNullP(this))
+            strLstAdd(result, pckReadStrP(this));
+    }
+    MEM_CONTEXT_TEMP_END();
 
     pckReadArrayEndP(this);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(STRING_LIST, result);
 }
 
 /**********************************************************************************************************************************/
@@ -1214,9 +1216,9 @@ pckReadTime(PackRead *this, PckReadTimeParam param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(TIME, param.defaultValue);
 
-    FUNCTION_TEST_RETURN((time_t)cvtInt64FromZigZag(pckReadTag(this, &param.id, pckTypeMapTime, false)));
+    FUNCTION_TEST_RETURN(TIME, (time_t)cvtInt64FromZigZag(pckReadTag(this, &param.id, pckTypeMapTime, false)));
 }
 
 /**********************************************************************************************************************************/
@@ -1232,9 +1234,9 @@ pckReadU32(PackRead *this, PckReadU32Param param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(UINT32, param.defaultValue);
 
-    FUNCTION_TEST_RETURN((uint32_t)pckReadTag(this, &param.id, pckTypeMapU32, false));
+    FUNCTION_TEST_RETURN(UINT32, (uint32_t)pckReadTag(this, &param.id, pckTypeMapU32, false));
 }
 
 /**********************************************************************************************************************************/
@@ -1250,9 +1252,9 @@ pckReadU64(PackRead *this, PckReadU64Param param)
     ASSERT(this != NULL);
 
     if (pckReadNullInternal(this, &param.id))
-        FUNCTION_TEST_RETURN(param.defaultValue);
+        FUNCTION_TEST_RETURN(UINT64, param.defaultValue);
 
-    FUNCTION_TEST_RETURN(pckReadTag(this, &param.id, pckTypeMapU64, false));
+    FUNCTION_TEST_RETURN(UINT64, pckReadTag(this, &param.id, pckTypeMapU64, false));
 }
 
 /**********************************************************************************************************************************/
@@ -1293,7 +1295,7 @@ pckWriteNewInternal(void)
 
     PackWrite *this = NULL;
 
-    OBJ_NEW_BEGIN(PackWrite)
+    OBJ_NEW_BEGIN(PackWrite, .childQty = MEM_CONTEXT_QTY_MAX)
     {
         this = OBJ_NEW_ALLOC();
 
@@ -1306,7 +1308,7 @@ pckWriteNewInternal(void)
     }
     OBJ_NEW_END();
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 PackWrite *
@@ -1318,13 +1320,13 @@ pckWriteNew(const PckWriteNewParam param)
 
     PackWrite *this = pckWriteNewInternal();
 
-    MEM_CONTEXT_BEGIN(objMemContext(this))
+    MEM_CONTEXT_OBJ_BEGIN(this)
     {
         this->buffer = bufNew(param.size == 0 ? PACK_EXTRA_MIN : param.size);
     }
-    MEM_CONTEXT_END();
+    MEM_CONTEXT_OBJ_END();
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 PackWrite *
@@ -1338,14 +1340,14 @@ pckWriteNewIo(IoWrite *write)
 
     PackWrite *this = pckWriteNewInternal();
 
-    MEM_CONTEXT_BEGIN(objMemContext(this))
+    MEM_CONTEXT_OBJ_BEGIN(this)
     {
         this->write = write;
         this->buffer = bufNew(ioBufferSize());
     }
-    MEM_CONTEXT_END();
+    MEM_CONTEXT_OBJ_END();
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /***********************************************************************************************************************************
@@ -1559,11 +1561,11 @@ pckWriteDefaultNull(PackWrite *this, bool defaultWrite, bool defaultEqual)
     if (!defaultWrite && defaultEqual)
     {
         this->tagStack.top->nullTotal++;
-        FUNCTION_TEST_RETURN(true);
+        FUNCTION_TEST_RETURN(BOOL, true);
     }
 
     // Let the caller know that it should write the value
-    FUNCTION_TEST_RETURN(false);
+    FUNCTION_TEST_RETURN(BOOL, false);
 }
 
 /**********************************************************************************************************************************/
@@ -1576,7 +1578,7 @@ pckWriteNull(PackWrite *this)
 
     this->tagStack.top->nullTotal++;
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1596,7 +1598,7 @@ pckWriteArrayBegin(PackWrite *this, PackIdParam param)
     // Add array to the tag stack so IDs can be tracked separately from the parent container
     pckTagStackPush(objMemContext(this), &this->tagStack, pckTypeMapArray);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 PackWrite *
@@ -1617,7 +1619,7 @@ pckWriteArrayEnd(PackWrite *this)
     // Pop array off the stack to revert to ID tracking for the prior container
     pckTagStackPop(&this->tagStack);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1647,7 +1649,7 @@ pckWriteBin(PackWrite *this, const Buffer *value, PckWriteBinParam param)
         }
     }
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1667,7 +1669,7 @@ pckWriteBool(PackWrite *this, bool value, PckWriteBoolParam param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapBool, param.id, value);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1687,7 +1689,7 @@ pckWriteI32(PackWrite *this, int32_t value, PckWriteI32Param param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapI32, param.id, cvtInt32ToZigZag(value));
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1707,7 +1709,7 @@ pckWriteI64(PackWrite *this, int64_t value, PckWriteI64Param param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapI64, param.id, cvtInt64ToZigZag(value));
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1727,7 +1729,7 @@ pckWriteMode(PackWrite *this, mode_t value, PckWriteModeParam param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapMode, param.id, value);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1747,7 +1749,7 @@ pckWriteObjBegin(PackWrite *this, PackIdParam param)
     // Add object to the tag stack so IDs can be tracked separately from the parent container
     pckTagStackPush(objMemContext(this), &this->tagStack, pckTypeMapObj);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 PackWrite *
@@ -1768,7 +1770,7 @@ pckWriteObjEnd(PackWrite *this)
     // Pop object off the stack to revert to ID tracking for the prior container
     pckTagStackPop(&this->tagStack);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1792,7 +1794,7 @@ pckWritePack(PackWrite *const this, const Pack *const value, const PckWritePackP
         pckWriteBuffer(this, (Buffer *)value);
     }
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1811,7 +1813,7 @@ pckWritePtr(PackWrite *this, const void *value, PckWritePtrParam param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == NULL))
         pckWriteTag(this, pckTypeMapPtr, param.id, (uintptr_t)value);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1841,7 +1843,7 @@ pckWriteStr(PackWrite *this, const String *value, PckWriteStrParam param)
         }
     }
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1861,7 +1863,7 @@ pckWriteStrId(PackWrite *this, uint64_t value, PckWriteStrIdParam param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapStrId, param.id, value);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1888,7 +1890,7 @@ pckWriteStrLst(PackWrite *const this, const StringList *const value, const PckWr
         pckWriteArrayEndP(this);
     }
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1908,7 +1910,7 @@ pckWriteTime(PackWrite *this, time_t value, PckWriteTimeParam param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapTime, param.id, cvtInt64ToZigZag(value));
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1928,7 +1930,7 @@ pckWriteU32(PackWrite *this, uint32_t value, PckWriteU32Param param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapU32, param.id, value);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1948,7 +1950,7 @@ pckWriteU64(PackWrite *this, uint64_t value, PckWriteU64Param param)
     if (!pckWriteDefaultNull(this, param.defaultWrite, value == param.defaultValue))
         pckWriteTag(this, pckTypeMapU64, param.id, value);
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1975,7 +1977,7 @@ pckWriteEnd(PackWrite *this)
     else
         bufResize(this->buffer, bufUsed(this->buffer));
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(PACK_WRITE, this);
 }
 
 /**********************************************************************************************************************************/
@@ -1995,7 +1997,7 @@ pckWriteResult(PackWrite *const this)
         result = (Pack *)this->buffer;
     }
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(PACK, result);
 }
 
 /**********************************************************************************************************************************/
