@@ -45,7 +45,7 @@ testRun(void)
     const char *helpVersion = PROJECT_NAME " " PROJECT_VERSION;
 
     // General help text is used in more than one test
-    const char *generalHelp = strZ(strNewFmt(
+    const char *generalHelp = zNewFmt(
         "%s - General help\n"
         "\n"
         "Usage:\n"
@@ -69,10 +69,11 @@ testRun(void)
         "    stanza-upgrade  Upgrade a stanza.\n"
         "    start           Allow pgBackRest processes to run.\n"
         "    stop            Stop pgBackRest processes from running.\n"
+        "    verify          Verify contents of the repository.\n"
         "    version         Get version.\n"
         "\n"
         "Use 'pgbackrest help [command]' for more information.\n",
-        helpVersion));
+        helpVersion);
 
     // *****************************************************************************************************************************
     if (testBegin("helpRenderSplitSize()"))
@@ -143,14 +144,14 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("version command");
 
-        const char *commandHelp = strZ(strNewFmt(
+        const char *commandHelp = zNewFmt(
             "%s%s",
             helpVersion,
             " - 'version' command help\n"
             "\n"
             "Get version.\n"
             "\n"
-            "Displays installed pgBackRest version.\n"));
+            "Displays installed pgBackRest version.\n");
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
@@ -163,7 +164,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("restore command");
 
-        commandHelp = strZ(strNewFmt(
+        commandHelp = zNewFmt(
             "%s%s%s",
             helpVersion,
             " - 'restore' command help\n"
@@ -177,13 +178,15 @@ testRun(void)
             "specific repository, the --repo option can be passed (e.g. --repo=1). The --set\n"
             "option can be passed if a backup other than the latest is desired.\n"
             "\n"
-            "When PITR of --type=time is specified, then the target time must be specified\n"
-            "with the --target option. If a backup is not specified via the --set option,\n"
-            "then the configured repositories will be checked, in order, for a backup that\n"
-            "contains the requested time. If no backup can be found, the latest backup from\n"
-            "the first repository containing backups will be used. For other types of PITR,\n"
-            "e.g. xid, the --set option must be provided if the target is prior to the\n"
-            "latest backup. See Point-in-Time Recovery for more details and examples.\n"
+            "When PITR of --type=time or --type=lsn is specified, then the target time or\n"
+            "target lsn must be specified with the --target option. If a backup is not\n"
+            "specified via the --set option, then the configured repositories will be\n"
+            "checked, in order, for a backup that contains the requested time or lsn. If no\n"
+            "matching backup is found, the latest backup from the first repository\n"
+            "containing backups will be used for --type=time while no backup will be\n"
+            "selected for --type=lsn. For other types of PITR, e.g. xid, the --set option\n"
+            "must be provided if the target is prior to the latest backup. See Point-in-Time\n"
+            "Recovery for more details and examples.\n"
             "\n"
             "Replication slots are not included per recommendation of PostgreSQL. See\n"
             "Backing Up The Data Directory in the PostgreSQL documentation for more\n"
@@ -315,7 +318,7 @@ testRun(void)
             "\n"
             "  --pg-path                        postgreSQL data directory\n"
             "\n"
-            "Use 'pgbackrest help restore [option]' for more information.\n"));
+            "Use 'pgbackrest help restore [option]' for more information.\n");
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
@@ -364,7 +367,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("default and current option value");
 
-        const char *optionHelp = strZ(strNewFmt(
+        const char *optionHelp = zNewFmt(
             "%s - 'archive-push' command - 'buffer-size' option help\n"
             "\n"
             "Buffer size for I/O operations.\n"
@@ -373,14 +376,9 @@ testRun(void)
             "of buffers used depends on options and each operation may use additional\n"
             "memory, e.g. gz compression may use an additional 256KiB of memory.\n"
             "\n"
-            "Size can be entered in bytes (default) or KiB, MiB, GiB, TiB, or PiB where the\n"
-            "multiplier is a power of 1024. For example, the case-insensitive value 5GiB (or\n"
-            "5GB, 5g) can be used instead of 5368709120. Fractional values such as 2.5GiB\n"
-            "are not allowed, use 2560MiB instead.\n"
-            "\n"
             "Allowed values are 16KiB, 32KiB, 64KiB, 128KiB, 256KiB, 512KiB, 1MiB, 2MiB,\n"
             "4MiB, 8MiB, and 16MiB.\n",
-            helpVersion));
+            helpVersion);
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
@@ -411,10 +409,10 @@ testRun(void)
         #define HELP_OPTION_DEPRECATED_NAMES                                                                                       \
             "deprecated names: repo-azure-host, repo-s3-host\n"
 
-        optionHelp = strZ(strNewFmt(
+        optionHelp = zNewFmt(
             HELP_OPTION
             HELP_OPTION_DEPRECATED_NAMES,
-            helpVersion));
+            helpVersion);
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
@@ -424,12 +422,12 @@ testRun(void)
         TEST_RESULT_VOID(testCfgLoad(argList), "help for archive-push command, repo1-s3-host option");
         TEST_RESULT_STR_Z(helpRender(helpData), optionHelp, "check text");
 
-        optionHelp = strZ(strNewFmt(
+        optionHelp = zNewFmt(
             HELP_OPTION
             "current: s3-host\n"
             "\n"
             HELP_OPTION_DEPRECATED_NAMES,
-            helpVersion));
+            helpVersion);
 
         // Set a current value for deprecated option name
         hrnCfgArgRawZ(argList, cfgOptRepoType, "s3");
@@ -440,7 +438,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("cipher pass redacted");
 
-        optionHelp = strZ(strNewFmt(
+        optionHelp = zNewFmt(
             "%s - 'archive-push' command - 'repo-cipher-pass' option help\n"
             "\n"
             "Repository cipher passphrase.\n"
@@ -448,7 +446,7 @@ testRun(void)
             "Passphrase used to encrypt/decrypt files of the repository.\n"
             "\n"
             "current: <redacted>\n",
-            helpVersion));
+            helpVersion);
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
@@ -464,7 +462,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("deprecated and new option name produce same results");
 
-        optionHelp = strZ(strNewFmt(
+        optionHelp = zNewFmt(
             "%s - 'backup' command - 'repo-hardlink' option help\n"
             "\n"
             "Hardlink files between backups in the repository.\n"
@@ -477,7 +475,7 @@ testRun(void)
             "default: n\n"
             "\n"
             "deprecated name: hardlink\n",
-            helpVersion));
+            helpVersion);
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
@@ -498,7 +496,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("check admonition");
 
-        optionHelp = strZ(strNewFmt(
+        optionHelp = zNewFmt(
             "%s - 'backup' command - 'repo-retention-archive' option help\n"
             "\n"
             "Number of backups worth of continuous WAL to retain.\n"
@@ -521,7 +519,7 @@ testRun(void)
             "expired WAL and is therefore not recommended.\n"
             "\n"
             "deprecated name: retention-archive\n",
-            helpVersion));
+            helpVersion);
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
