@@ -99,7 +99,7 @@ testSuite(CompressType type, const char *decompressCmd)
     TEST_TITLE("compressed output can be decompressed with command-line tool");
 
     storagePutP(storageNewWriteP(storageTest, STRDEF("test.cmp")), compressed);
-    HRN_SYSTEM_FMT("%s " TEST_PATH "/test.cmp > " TEST_PATH "/test.out", decompressCmd);
+    HRN_SYSTEM_FMT("%s " TEST_PATH "/test.cmp > " TEST_PATH "/test.out 2> /dev/null", decompressCmd);
     TEST_RESULT_BOOL(bufEq(decompressed, storageGetP(storageNewReadP(storageTest, STRDEF("test.out")))), true, "check output");
 
     TEST_RESULT_BOOL(
