@@ -134,7 +134,7 @@ testRun(void)
         TEST_TITLE("set error handler");
 
         static const ErrorHandlerFunction testErrorHandlerList[] = {testErrorHandler};
-        errorHandlerSet(testErrorHandlerList, sizeof(testErrorHandlerList) / sizeof(ErrorHandlerFunction));
+        errorHandlerSet(testErrorHandlerList, LENGTH_OF(testErrorHandlerList));
 
         assert(errorContext.handlerList[0] == testErrorHandler);
         assert(errorContext.handlerTotal == 1);
@@ -157,12 +157,22 @@ testRun(void)
                     TRY_BEGIN()
                     {
                         assert(errorTryDepth() == 4);
-                        tryDone = true;
 
-                        char bigMessage[sizeof(messageBuffer) + 128];
-                        memset(bigMessage, 'A', sizeof(bigMessage));
+                        TRY_BEGIN()
+                        {
+                            assert(errorTryDepth() == 5);
+                            tryDone = true;
+                        }
+                        FINALLY()
+                        {
+                            assert(errorContext.tryList[5].state == errorStateTry);
 
-                        THROW(AssertError, bigMessage);
+                            char bigMessage[sizeof(messageBuffer) + 128];
+                            memset(bigMessage, 'A', sizeof(bigMessage));
+
+                            THROW(AssertError, bigMessage);
+                        }
+                        TRY_END();
                     }
                     CATCH_ANY()
                     {
@@ -403,6 +413,9 @@ testRun(void)
         {
             HRN_FORK_CHILD_BEGIN(.expectedExitStatus = UnhandledError.code)
             {
+                // Redirect stderr to stdout (we do not care about the output here since coverage will tell us we hit the code)
+                stderr = stdout;
+
                 THROW(TestChildError, "does not get caught!");
             }
             HRN_FORK_CHILD_END();
