@@ -47,13 +47,12 @@ testComparator(const void *item1, const void *item2)
 Test callback to count ini load results
 ***********************************************************************************************************************************/
 static void
-testIniLoadCountCallback(void *data, const String *section, const String *key, const String *value, const Variant *valueVar)
+testIniLoadCountCallback(void *const data, const String *const section, const String *const key, const String *const value)
 {
     (*(unsigned int *)data)++;
     (void)section;
     (void)key;
     (void)value;
-    (void)valueVar;
 }
 
 /***********************************************************************************************************************************
@@ -94,17 +93,17 @@ storageTestManifestNewBuildInfo(THIS_VOID, const String *file, StorageInfoLevel
     return result;
 }
 
-static bool
-storageTestManifestNewBuildInfoList(
-    THIS_VOID, const String *path, StorageInfoLevel level, StorageInfoListCallback callback, void *callbackData,
-    StorageInterfaceInfoListParam param)
+static StorageList *
+storageTestManifestNewBuildList(THIS_VOID, const String *path, StorageInfoLevel level, StorageInterfaceListParam param)
 {
     THIS(StorageTestManifestNewBuild);
     (void)path; (void)level; (void)param;
 
+    StorageList *const result = storageLstNew(storageInfoLevelDetail);
+
     MEM_CONTEXT_TEMP_RESET_BEGIN()
     {
-        StorageInfo result =
+        StorageInfo info =
         {
             .level = storageInfoLevelDetail,
             .exists = true,
@@ -118,25 +117,25 @@ storageTestManifestNewBuildInfoList(
 
         if (strEq(path, STRDEF("/pg")))
         {
-            result.name = STRDEF("base");
-            callback(callbackData, &result);
+            info.name = STRDEF("base");
+            storageLstAdd(result, &info);
         }
         else if (strEq(path, STRDEF("/pg/base")))
         {
-            result.name = STRDEF("1000000000");
-            callback(callbackData, &result);
+            info.name = STRDEF("1000000000");
+            storageLstAdd(result, &info);
         }
         else if (strEq(path, STRDEF("/pg/base/1000000000")))
         {
-            result.type = storageTypeFile;
-            result.size = 8192;
-            result.mode = 0600;
-            result.timeModified = 1595627966;
+            info.type = storageTypeFile;
+            info.size = 8192;
+            info.mode = 0600;
+            info.timeModified = 1595627966;
 
             for (unsigned int fileIdx = 0; fileIdx < this->fileTotal; fileIdx++)
             {
-                result.name = strNewFmt("%u", 1000000000 + fileIdx);
-                callback(callbackData, &result);
+                info.name = strNewFmt("%u", 1000000000 + fileIdx);
+                storageLstAdd(result, &info);
                 MEM_CONTEXT_TEMP_RESET(10000);
             }
         }
@@ -145,7 +144,7 @@ storageTestManifestNewBuildInfoList(
     }
     MEM_CONTEXT_TEMP_END();
 
-    return true;
+    return result;
 }
 
 /***********************************************************************************************************************************
@@ -256,7 +255,7 @@ testRun(void)
         };
 
         driver.interface.info = storageTestManifestNewBuildInfo;
-        driver.interface.infoList = storageTestManifestNewBuildInfoList;
+        driver.interface.list = storageTestManifestNewBuildList;
 
         const Storage *const storagePg = storageNew(
             strIdFromZ("test"), STRDEF("/pg"), 0, 0, false, NULL, &driver, driver.interface);
@@ -264,7 +263,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("build manifest");
 
-        MemContext *testContext = memContextNewP("test");
+        MemContext *testContext = memContextNewP("test", .childQty = MEM_CONTEXT_QTY_MAX);
         memContextKeep();
         Manifest *manifest = NULL;
         TimeMSec timeBegin = timeMSec();
@@ -277,7 +276,7 @@ testRun(void)
         MEM_CONTEXT_END();
 
         TEST_LOG_FMT("completed in %ums", (unsigned int)(timeMSec() - timeBegin));
-        TEST_LOG_FMT("memory used %zu", memContextSize(testContext));
+        // TEST_LOG_FMT("memory used %zu", memContextSize(testContext));
 
         TEST_RESULT_UINT(manifestFileTotal(manifest), driver.fileTotal, "   check file total");
 
@@ -296,7 +295,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("load manifest");
 
-        testContext = memContextNewP("test");
+        testContext = memContextNewP("test", .childQty = MEM_CONTEXT_QTY_MAX);
         memContextKeep();
         timeBegin = timeMSec();
 
@@ -307,7 +306,7 @@ testRun(void)
         MEM_CONTEXT_END();
 
         TEST_LOG_FMT("completed in %ums", (unsigned int)(timeMSec() - timeBegin));
-        TEST_LOG_FMT("memory used %zu", memContextSize(testContext));
+        // TEST_LOG_FMT("memory used %zu", memContextSize(testContext));
 
         TEST_RESULT_UINT(manifestFileTotal(manifest), driver.fileTotal, "   check file total");
 
@@ -352,18 +351,6 @@ testRun(void)
         }
 
         TEST_LOG_FMT("completed in %ums", (unsigned int)(timeMSec() - timeBegin));
-
-        // -------------------------------------------------------------------------------------------------------------------------
-        TEST_TITLE("check stats have correct values");
-
-        KeyValue *statKv = statToKv();
-
-        for (unsigned int statIdx = 0; statIdx < TEST_STAT_TOTAL; statIdx++)
-        {
-            TEST_RESULT_UINT(
-                varUInt64(kvGet(varKv(kvGet(statKv, VARSTR(statList[statIdx]))), STAT_VALUE_TOTAL_VAR)), runTotal,
-                strZ(strNewFmt("check stat %u", statIdx)));
-        }
     }
 
     // *****************************************************************************************************************************
